// Copyright 2016-2019 Cargo-Bundle developers <https://github.com/burtonageo/cargo-bundle>
// Copyright 2019-2024 Tauri Programme within The Commons Conservancy
// SPDX-License-Identifier: Apache-2.0
// SPDX-License-Identifier: MIT

pub mod appimage;
pub mod debian;
pub mod freedesktop;
pub mod rpm;

mod util;

#[cfg(target_os = "linux")]
pub use util::patch_binary;
